@@ -3,7 +3,7 @@ from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from rest_framework.serializers import SerializerMethodField
 
-EventDataDownload = import_string('EVENT.data_download.models')
+EventDataDownload = import_string('event.data_download.models')
 
 
 class EventDataDownloadSerializer(CustomSerializer):
