@@ -3,8 +3,8 @@ from rest_framework.serializers import SerializerMethodField, CharField, Integer
 from bluedot_rest_framework import import_string
 
 
-Event = import_string('EVENT.models')
-EventRegister = import_string('EVENT.register.models')
+Event = import_string('event.models')
+EventRegister = import_string('event.register.models')
 
 
 class EventRegisterSerializer(CustomSerializer):
