@@ -3,11 +3,11 @@ from rest_framework.response import Response
 
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create
-from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
 
 
-EventRegister = import_string('EVENT.register.models')
-EventRegisterSerializer = import_string('EVENT.register.serializers')
+EventRegister = import_string('event.register.models')
+EventRegisterSerializer = import_string('event.register.serializers')
 
 
 class EventRegisterView(CustomModelViewSet):
@@ -30,9 +30,9 @@ class EventRegisterView(CustomModelViewSet):
     @action(detail=False, methods=['get'], url_path='state', url_name='state')
     def state(self, request, *args, **kwargs):
         event_id = request.query_params.get('event_id', None)
-        user_id = jwt_get_userid_handler(self.request.auth)
+        wechat_id = jwt_get_wechatid_handler(request.auth)
         queryset = self.model_class.objects.filter(
-            user_id=user_id, event_id=event_id).first()
+            wechat_id=wechat_id, event_id=event_id).first()
         state = -1
         if queryset:
             state = queryset.state
