@@ -3,7 +3,7 @@ from datetime import datetime
 from django.conf import settings
 from rest_framework_jwt.settings import api_settings
 from rest_framework_jwt.utils import jwt_get_secret_key
-
+from bluedot_rest_framework.wechat.models import WeChatUser, WeChatUserOpenid
 from bluedot_rest_framework.api_auth.serializers import AuthUserSerializer
 
 
@@ -14,13 +14,13 @@ def jwt_response_payload_handler_admin(token, user=None, request=None):
     }
 
 
-def jwt_payload_handler_wehat(openid, unionid, userid, wechat_id):
+def jwt_payload_handler_wehat(wechat_id, unionid):
     payload = {
         'user_id': settings.JWT_AUTH['SUPERUSER_ID'],
         'username': settings.JWT_AUTH['SUPERUSER_NAME'],
-        'openid': openid,
+        # 'openid': openid,
         'unionid': unionid,
-        'userid': userid,
+        # 'userid': userid,
         'wechat_id': wechat_id,
         'exp': datetime.now() + api_settings.JWT_EXPIRATION_DELTA
     }
@@ -35,13 +35,13 @@ def jwt_payload_handler_wehat(openid, unionid, userid, wechat_id):
     return payload
 
 
-def jwt_create_token_wechat(openid, unionid, userid='', wechat_id=''):
+def jwt_create_token_wechat(wechat_id, unionid=''):
     """
     创建token
     """
     jwt_encode_handler = api_settings.JWT_ENCODE_HANDLER
 
-    payload = jwt_payload_handler_wehat(openid, unionid, userid, wechat_id)
+    payload = jwt_payload_handler_wehat(wechat_id, unionid)
     token = jwt_encode_handler(payload)
     return token
 
@@ -66,21 +66,19 @@ def jwt_decode_handler_wechat(token):
     )
 
 
-def jwt_get_openid_handler(token):
-    return jwt_decode_handler_wechat(token)['openid']
-
-
 def jwt_get_unionid_handler(token):
     return jwt_decode_handler_wechat(token)['unionid']
 
 
-def jwt_get_userid_handler(token):
-    return jwt_decode_handler_wechat(token)['userid']
-
-
 def jwt_get_wechatid_handler(token):
     return jwt_decode_handler_wechat(token)['wechat_id']
 
 
 def jwt_get_userinfo_handler(token):
-    return jwt_get_userid_handler(token), jwt_get_openid_handler(token), jwt_get_unionid_handler(token), jwt_get_wechatid_handler(token)
+    return jwt_get_wechatid_handler(token), jwt_get_unionid_handler(token)
+
+
+def jwt_get_openid_handler(token, appid):
+    wechat_id = jwt_get_wechatid_handler(token)
+    queryset = WeChatUser.objects.get(pk=wechat_id)
+    return WeChatUserOpenid.objects.get(wechat_id=queryset.pk, appid=appid).openid
