@@ -3,7 +3,8 @@ from rest_framework.routers import DefaultRouter
 from .response.views import WeChatResponseEventView, WeChatResponseMaterialView
 from .response.response import Response
 from .login.views import WeChatLoginView, WeChatLoginWebSocketView
-from .views import JSSdk, OAuth, Token, Menu, Current
+from .views import JSSdk, OAuth, Menu, Current
+# from .response.qrcode import WeChatQrcodeView
 
 router = DefaultRouter(trailing_slash=False)
 
@@ -14,10 +15,10 @@ router.register(r'wechat/response/event', WeChatResponseEventView,
 urlpatterns = router.urls
 
 urlpatterns += [
+    # url(r'^wechat/qrcode', WeChatQrcodeView.as_view()),
     url(r'^wechat/current', Current.as_view()),
     url(r'^wechat/response', Response.as_view()),
     url(r'^wechat/oauth', OAuth.as_view()),
-    url(r'^wechat/token', Token.as_view()),
     url(r'^wechat/jssdk', JSSdk.as_view()),
     url(r'^wechat/menu', Menu.as_view()),
     url(r'^wechat/login-websocket', WeChatLoginWebSocketView.as_view()),
